#ifndef _FTAPE_DYNMEM_H
#define _FTAPE_DYNMEM_H
/*
 *      Copyright (C) 1994 Claus-Justus Heine.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 $Source: /homes/cvs/zftape/zftape-buffers.h,v $
 $Author: claus $
 *
 $Revision: 1.10 $
 $Date: 1996/08/31 00:48:53 $
 $State: Exp $
 *
 *   memory allocation routines. Tries to use remaining parts of dma-buffer
 *   (wich is aligned to 32k) for ordinary buffers. 
 *
 */

/*
 *  we do not allocate all of the really large buffer memory before
 *  someone tries to open the drive. ftape_open() may fail
 *  with -ENOMEM, but that's better having 200k of vmalloced
 *  memory which cannot be swapped out.
 * 
 *  This does not work for older kernels. Therefor OLD_DYN_DMA
 *
 *  I do some macro hacks to keep that allocation code concentrated
 *  in the two files zftape-buffers.c and zftape-buffers.h
 */

#ifndef NR_BUFFERS
# define NR_BUFFERS 3
#endif

#define SIZEOF(name) sizeof(__sizeof_hack_##name)
#define DECLARE_BUFFER(type,name,count) extern type *name; extern type __sizeof_hack_##name[ count ]
#define DEFINE_BUFFER(type,name,count) type *name=NULL

/*
 *   called by init_module()
 */
extern int zftape_init_mem( void );
/*
 * called by cleanup_module()
 */
extern void zftape_uninit_mem( void );
/*
 *  called by ftape_open();
 */
extern int  zftape_get_tape_buffers( kdev_t device_number );
/*
 *   called by ftape_close();
 */
extern void zftape_unget_tape_buffers( void );
/*
 *   called by ftape_zap_read_buffers();
 */
extern void zftape_init_tape_buffer ( void );
/*
 *   called via MTSETDRVBUFFER
 */
extern int  zftape_change_dma_size( int num_buffers );
/*
 *  as the compression map gets really large for big tapes, we do not
 *  allocate it before we need it. That is, we place a call to this 
 *  function before actually reading the compression map and
 *  we release the compression map whenever the drive is opened 
 *  and we detect that a new tape has been inserted. 
 */
extern int zftape_allocate_compression_map( void );
extern void zftape_release_compression_map( void );
/*
 *  do nearly the same for the bad_sector_map. This saves another
 *  27 kb of memory if the driver is offline
 */
extern int zftape_allocate_bad_sector_map( void );
extern void zftape_release_bad_sector_map( void );
/*
 *  do the same for the internal volume table. 
 */
extern int zftape_allocate_qic80_vtbl( void );
extern void zftape_release_qic80_vtbl( void );
/*
 *  this one stores the number of 32k buffers currently allocated
 */
extern int ftape_num_buffers;

#endif







